@@ -1,5 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.6.5'
-from base import Choices
+__version__ = '0.8.0'
+from .base import Choices
